Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(45)

Unified Diff: pkg/dartino_compiler/lib/src/verbs/actions.dart

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/dartino_compiler/lib/src/verbs/README.md ('k') | pkg/dartino_compiler/lib/src/verbs/attach_verb.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/dartino_compiler/lib/src/verbs/actions.dart
diff --git a/pkg/fletchc/lib/src/verbs/actions.dart b/pkg/dartino_compiler/lib/src/verbs/actions.dart
similarity index 95%
rename from pkg/fletchc/lib/src/verbs/actions.dart
rename to pkg/dartino_compiler/lib/src/verbs/actions.dart
index ceb108a486dcfa7f4a430899985d68b76c9b3572..11908dc661452a9d26c151db5a0bcd17afb418d0 100644
--- a/pkg/fletchc/lib/src/verbs/actions.dart
+++ b/pkg/dartino_compiler/lib/src/verbs/actions.dart
@@ -2,7 +2,7 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE.md file.
-library fletchc.verbs.verbs;
+library dartino_compiler.verbs.verbs;
import 'infrastructure.dart' show
AnalyzedSentence,
@@ -110,7 +110,7 @@ class Action {
///
/// Please make sure their combined documentation fit in in 80 columns by 20
/// lines. The default terminal size is normally 80x24. Two lines are used
/// for the prompts before and after running fletch. Another two lines may be
/// used to print an error message.
const Map<String, Action> commonActions = const <String, Action>{
"help": helpAction,
@@ -121,7 +121,7 @@ const Map<String, Action> commonActions = const <String, Action>{
/// Uncommon verbs aren't displayed in the normal help screen.
///
/// These verbs are displayed when running `fletch help all`.
const Map<String, Action> uncommonActions = const <String, Action>{
"attach": attachAction,
"compile": compileAction,
@@ -110,7 +110,7 @@ class Action {
/// Please make sure their combined documentation fit in in 80 columns by 20
/// lines. The default terminal size is normally 80x24. Two lines are used
-/// for the prompts before and after running fletch. Another two lines may be
+/// for the prompts before and after running dartino. Another two lines may be
/// used to print an error message.
const Map<String, Action> commonActions = const <String, Action>{
@@ -121,7 +121,7 @@ const Map<String, Action> commonActions = const <String, Action>{
/// Uncommon verbs aren't displayed in the normal help screen.
///
-/// These verbs are displayed when running `fletch help all`.
+/// These verbs are displayed when running `dartino help all`.
const Map<String, Action> uncommonActions = const <String, Action>{
"attach": attachAction,
« no previous file with comments | « pkg/dartino_compiler/lib/src/verbs/README.md ('k') | pkg/dartino_compiler/lib/src/verbs/attach_verb.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698